@@ -157,9 +157,19 @@ db.list <- function ()
 ## ------------------------------------------------------------------------
 
 ## list tables and views in the connection
-db.objects <- function (conn.id = 1)
+db.objects <- function (search = NULL, conn.id = 1)
 {
-    .db.getQuery("select table_schema, table_name from information_schema.tables")
+    res <- .db.getQuery("select table_schema, table_name from information_schema.tables")
+    if (is.null(search)) return (res)
+    search <- gsub("\\.", "\\\\.", search)
+    final.res <- character(0)
+    for (i in seq_len(dim(res)[1])) {
+        name <- paste(res[i,1], ".", res[i,2], sep = "")
+        find <- gsub(search, "", name)
+        if (find != name)
+            final.res <- rbind(final.res, res[i,])
+    }
+    final.res
 }
 
 ## ------------------------------------------------------------------------
@@ -247,9 +257,22 @@ db.existsObject <- function (name, conn.id = 1, is.temp = FALSE)
 .db.existsTable <- function (table, conn.id = 1)
 {
     id <- .localVars$conn.id[.localVars$conn.id[,1] == conn.id, 2]
-    command <- paste(".db.existsTable.", .localVars$db[[id]]$conn.pkg,
-                     "(table=table, idx=id)", sep = "")
-    eval(parse(text = command))
+    ## command <- paste(".db.existsTable.", .localVars$db[[id]]$conn.pkg,
+    ##                  "(table=table, idx=id)", sep = "")
+    ## eval(parse(text = command))
+    if (length(table) == 1) {
+        schema.str <- ""
+        tbl.name <- table
+    } else {
+        schema.str <- paste(" and table_schema = '", table[1], "'", sep = "")
+        tbl.name <- table[2]
+    }
+    ct <- .db.getQuery(paste("select count(*) from information_schema.tables where table_name = '",
+                             tbl.name, "'", schema.str, sep = ""), conn.id)
+    if (ct == 0)
+        FALSE
+    else
+        TRUE
 }
 
 ## ------------------------------------------------------------------------
@@ -308,7 +331,7 @@ db.existsObject <- function (name, conn.id = 1, is.temp = FALSE)
     id <- .localVars$conn.id[.localVars$conn.id[,1] == conn.id, 2]
     command <- paste(".db.writeTable.", .localVars$db[[id]]$conn.pkg,
                      "(table=table, r.obj=r.obj, add.row.names=add.row.names,
-                      overwrite=overwrite, append=append, conn.id=conn.id,
+                      overwrite=overwrite, append=append,
                       distributed.by=distributed.by,
                       is.temp=is.temp, idx=id,
                       header=header, nrows=nrows, sep=sep, eol=eol,
