@@ -122,7 +122,7 @@ setMethod (
     def = function (x, table.name, verbose = FALSE,
     is.view = FALSE,
     is.temp = FALSE,  pivot = TRUE,
-    distributed.by = NULL) {
+    distributed.by = NULL, nrow = NULL) {
         conn.id <- conn.id(x)
 
         dist.str <- .get.distributed.by.str(conn.id, distributed.by)
@@ -153,7 +153,7 @@ setMethod (
         extra <- paste(x@.expr, paste("\"", names(x), "\"", sep = ""),
                        sep = " as ", collapse = ",")
         ## suffix used to avoid conflicts
-        suffix <- rep("", length(x@.is.factor))
+        suffix <- x@.factor.suffix
         appear <- x@.col.name
         is.factor <- x@.is.factor
         
@@ -169,11 +169,12 @@ setMethod (
             sql <- paste(sql, " from ", tbl, sep = "")
             distincts <- .db.getQuery(sql, conn.id)
             idx <- 0
+            dummy <- character(0)
+            dummy.expr <- character(0)
             for (i in seq_len(length(x@.is.factor))) {
                 if (x@.is.factor[i]) {
                     idx <- idx + 1
                     distinct <- as.vector(arraydb.to.arrayr(distincts[[paste("distinct_",idx,sep="")]], "character"))
-                    suffix[i] <- .unique.string()
                     ## Produce a fixed order for distinct values
                     distinct <- distinct[order(distinct, decreasing = TRUE)]
                     for (j in seq_len(length(distinct) - 1)) {
@@ -181,12 +182,15 @@ setMethod (
                                         distinct[j], sep = "")
                         is.factor <- c(is.factor, FALSE)
                         if (extra != "") extra <- paste(extra, ", ")
-                        extra <- paste(extra, " (case when ", x@.expr[i], " = '",
-                                       distinct[j], "'::", x@.col.data_type[i],
-                                       " then 1 else 0 end) as ",
+                        dex <- paste("(case when ", x@.expr[i], " = '",
+                                     distinct[j], "'::", x@.col.data_type[i],
+                                     " then 1 else 0 end)", sep = "")
+                        extra <- paste(extra, " ", dex, " as ",
                                        "\"", new.col, "\"", sep = "")
                         appear <- c(appear, paste(x@.col.name[i],":",
                                                   distinct[j], sep = ""))
+                        dummy <- c(dummy, new.col)
+                        dummy.expr <- c(dummy.expr, dex)
                     }
                 } 
             }
@@ -196,12 +200,17 @@ setMethod (
             where <- paste(" where", x@.where)
         else
             where <- ""
+
+        if (!is.null(nrow))
+            nrow.str <- paste(" limit ", nrow, " ", sep = "")
+        else
+            nrow.str <- ""
         
         content.str <- paste("select ", extra, " from ", tbl, where, sep = "")
                 
         create.str <- paste("create ", temp.str, " ", obj.str, " \"",
                             table.name,
-                            "\" as (", content.str, ") ", dist.str, sep = "")
+                            "\" as (", content.str, nrow.str, ") ", dist.str, sep = "")
 
         .db.getQuery(create.str, conn.id) # create table
         ## print(create.str)
@@ -210,5 +219,7 @@ setMethod (
         res@.is.factor <- is.factor
         res@.factor.suffix <- suffix
         res@.appear.name <- appear
+        res@.dummy <- dummy
+        res@.dummy.expr <- dummy.expr
         list(res = res, conn.id = conn.id)
     })
