@@ -60,6 +60,9 @@ setMethod (
 
         col.idx.y <- .gwhich(names(y), by.y)
         is.factor <- x@.is.factor[col.idx] & y@.is.factor[col.idx.y]
+        factor.suffix <- rep("", length(is.factor))
+        for (i in seq_len(length(factor.suffix))) # create new suffix
+            if (is.factor[i]) factor.suffix[i] <- .unique.string()
         
         col.name <- by.x
         x.diff <- setdiff(names(x), by.x)
@@ -71,6 +74,7 @@ setMethod (
             col.data_type <- c(col.data_type, x@.col.data_type[idx])
             col.udt_name <- c(col.udt_name, x@.col.udt_name[idx])
             is.factor <- c(is.factor, x@.is.factor[idx])
+            factor.suffix <- c(factor.suffix, x@.factor.suffix[idx])
             if (col %in% xy) {
                 others <- c(others, paste("s.\"", col, "\"", sep = ""))
                 col.name <- c(col.name, paste(col, suffixes[1], sep = ""))
@@ -84,6 +88,7 @@ setMethod (
             col.data_type <- c(col.data_type, y@.col.data_type[idx])
             col.udt_name <- c(col.udt_name, y@.col.udt_name[idx])
             is.factor <- c(is.factor, y@.is.factor[idx])
+            factor.suffix <- c(factor.suffix, y@.factor.suffix[idx])
             if (col %in% xy) {
                 others <- c(others, paste("t.\"", col, "\"", sep = ""))
                 col.name <- c(col.name, paste(col, suffixes[2], sep = ""))
@@ -114,6 +119,7 @@ setMethod (
             .col.udt_name = col.udt_name,
             .where = "",
             .is.factor = is.factor,
+            .factor.suffix = factor.suffix,
             .sort = list(by = "", order = "", str = ""))
     },
     valueClass = "db.Rquery")
